# Madoc


## What is Madoc for ?

It is a terminal tool to automatically generate a single html documentation file from all
the .md files found in the directory.

Cool stuff to join a clean and easy to read documentation to some project.


# Installation

`pip install madoc`


# Usage

Open a terminal in the directory where the .md files are,
and just type:

`madoc`

done, you have your documentation in a single html file.

Know more options with `madoc -h`.

# Changelog

1.1.1: responsive design
1.1.0: Recursive build mode